==> wordlecli-0.1.4.tar.gz: wordlecli-0.1.4/README.md <==
<h2 align="center"> ━━━━━━  ❖  ━━━━━━ </h2>

<!-- BADGES -->
<div align="center">
   <p></p>
   
   <img src="https://img.shields.io/github/stars/zenithds/wordle-cli?color=F8BD96&labelColor=302D41&style=for-the-badge">   

   <img src="https://img.shields.io/github/forks/zenithds/wordle-cli?color=DDB6F2&labelColor=302D41&style=for-the-badge">   

   <img src="https://img.shields.io/github/repo-size/zenithds/wordle-cli?color=ABE9B3&labelColor=302D41&style=for-the-badge">
   
   <img src="https://badges.pufler.dev/visits/zenithds/wordle-cli?style=for-the-badge&color=96CDFB&logoColor=white&labelColor=302D41"/>
   <br>
</div>

<p/>

---

### ❖ Information 

  wordle-cli is, as the name suggests, wordle in the command-line. There are no fancy gui/tui elements, just a simple an minimalistic way to play wordle :)

  <img src="assets/wordle.gif" alt="wordle preview">

---

### ❖ Installation

> Install from pip
```sh
$ pip3 install wordlecli
```

> Install from source
- First, install [poetry](https://python-poetry.org/)
```sh
$ git clone https://github.com/ZenithDS/wordle-cli.git
$ cd wordle-cli
$ poetry install
```

### ❖ Usage 

playing wordle in the command-line is as simple as running the following command:

```sh
$ wordle
```

but if your addiction to wordle needs more, you can also play an older wordle by specifying the it's number

```sh
$ wordle 240
```

---

### ❖ What's New? 
0.1.4 - fixed the logic for word comparison

---

<div align="center">

   <img src="https://img.shields.io/static/v1.svg?label=License&message=MIT&color=F5E0DC&labelColor=302D41&style=for-the-badge">

</div>

==> wordlecli-0.2.0.tar.gz: wordlecli-0.2.0/README.md <==
<h2 align="center"> ━━━━━━  ❖  ━━━━━━ </h2>

<!-- BADGES -->
<div align="center">
   <p></p>
   
   <img src="https://img.shields.io/github/stars/zenithds/wordle-cli?color=F8BD96&labelColor=302D41&style=for-the-badge">   

   <img src="https://img.shields.io/github/forks/zenithds/wordle-cli?color=DDB6F2&labelColor=302D41&style=for-the-badge">   

   <img src="https://img.shields.io/github/repo-size/zenithds/wordle-cli?color=ABE9B3&labelColor=302D41&style=for-the-badge">
   
   <img src="https://badges.pufler.dev/visits/zenithds/wordle-cli?style=for-the-badge&color=96CDFB&logoColor=white&labelColor=302D41"/>
   <br>
</div>

<p/>

---

### ❖ Information 

  wordle-cli is, as the name suggests, wordle in the command-line. There are no fancy gui/tui elements, just a simple and minimalistic way to play wordle :)

  <img src="assets/wordle.gif" alt="wordle preview">

---

### ❖ Installation

> Install from pip
```sh
$ pip3 install wordlecli
```

> Install from source
- First, install [poetry](https://python-poetry.org/)
```sh
$ git clone https://github.com/ZenithDS/wordle-cli.git
$ cd wordle-cli
$ poetry install
```

### ❖ Usage 

playing wordle in the command-line is as simple as running the following command:

```sh
$ wordle
```

but if your addiction to wordle needs more, you can also play an older wordle by specifying it's number

```sh
$ wordle 240
```

---

### ❖ What's New? 
0.2.0 - Added an on-screen-keyboard by default - can be toggled via cli option 

---

<div align="center">

   <img src="https://img.shields.io/static/v1.svg?label=License&message=MIT&color=F5E0DC&labelColor=302D41&style=for-the-badge">

</div>
